# redux-toolkit

This is a python package for redux-like state management in Python. It is designed to be simple and easy to use, while still providing powerful features for managing state in your applications.
